@@ -1,6 +1,6 @@
 package Map::Tube::Tokyo::Line::Chiyoda;
 
-$Map::Tube::Tokyo::Line::Chiyoda::VERSION   = '0.59';
+$Map::Tube::Tokyo::Line::Chiyoda::VERSION   = '0.60';
 $Map::Tube::Tokyo::Line::Chiyoda::AUTHORITY = 'cpan:MANWAR';
 
 use 5.006;
@@ -14,7 +14,7 @@ Map::Tube::Tokyo::Line::Chiyoda - Tokyo Subway Map: Chiyoda Line.
 
 =head1 VERSION
 
-Version 0.59
+Version 0.60
 
 =head1 DESCRIPTION
 
@@ -98,7 +98,7 @@ map generated by plugin L<Map::Tube::Plugin::Graph>.
 
 =head1 AUTHOR
 
-Mohammad S Anwar, C<< <mohammad.anwar at yahoo.com> >>
+Mohammad Sajid Anwar, C<< <mohammad.anwar at yahoo.com> >>
 
 =head1 REPOSITORY
 
@@ -106,8 +106,7 @@ L<https://github.com/manwar/Map-Tube-Tokyo>
 
 =head1 BUGS
 
-Please  report any bugs/feature requests to C<bug-map-tube-tokyo at rt.cpan.org>,
-or through the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Map-Tube-Tokyo>.
+Please  report any bugs/feature requests through the web interface at L<https://github.com/manwar/Map-Tube-Tokyo/issues>.
 I will be notified, and then you'll automatically be notified of progress on your
 bug as I make changes.
 
@@ -115,15 +114,15 @@ bug as I make changes.
 
 You can find documentation for this module with the perldoc command.
 
-    perldoc Map::Tube::Tokyo::Line::Chiyoda
+    perldoc Map::Tube::Tokyo
 
 You can also look for information at:
 
 =over 4
 
-=item * RT: CPAN's request tracker (report bugs here)
+=item * BUG Report
 
-L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Map-Tube-Tokyo>
+L<https://github.com/manwar/Map-Tube-Tokyo/issues>
 
 =item * AnnoCPAN: Annotated CPAN documentation
 
@@ -133,15 +132,15 @@ L<http://annocpan.org/dist/Map-Tube-Tokyo>
 
 L<http://cpanratings.perl.org/d/Map-Tube-Tokyo>
 
-=item * Search CPAN
+=item * Search MetaCPAN
 
-L<http://search.cpan.org/dist/Map-Tube-Tokyo/>
+L<https://metacpan.org/dist/Map-Tube-Tokyo>
 
 =back
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright (C) 2014 - 2016 Mohammad S Anwar.
+Copyright (C) 2014 - 2024 Mohammad Sajid Anwar.
 
 This program  is  free software; you can redistribute it and / or modify it under
 the  terms  of the the Artistic License  (2.0). You may obtain a copy of the full
